@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11907 2020-02-06 03:48:51Z Trista $
+# $Id: views.py 11930 2020-02-18 16:03:26Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and 
 # limitations under the License.
 #
-# $Author: Trista $
-# $Date: 2020-02-06 11:48:51 +0800 (週四, 06 二月 2020) $
-# $Revision: 11907 $ 
+# $Author: Lavender $
+# $Date: 2020-02-19 01:03:26 +0900 (週三, 19 二月 2020) $
+# $Revision: 11930 $ 
 
 import json
 import logging
@@ -280,7 +280,7 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
                 )
         
         # bonus   
-        config = BonusSettings.objects.get()
+        config, created = BonusSettings.objects.get_or_create(id=1)
         
         if user.is_authenticated:
             b, created = Bonus.objects.get_or_create(user=user)
@@ -727,6 +727,19 @@ def updateBonus(request, *args, **kwargs):
         request, _("Update success"))
     
     return redirect(reverse("dashboard:user-detail", kwargs={'pk': pk,}))
+    
+# paypal patch
+# https://www.paypal-community.com/t5/Sandbox-Environment/
+# You-are-not-signed-up-to-accept-payment-for-digitally-delivered/td-p/1468047
+from paypal.express import gateway
+
+originFetchResponse = gateway._fetch_response
+def newFetchResponse(method, extraParams):
+    newExtraParams = {k: v for k, v in extraParams.items() if not k.startswith("L_PAYMENTREQUEST_0_ITEMCATEGORY")}
+    
+    return originFetchResponse(method, newExtraParams)
+    
+gateway._fetch_response = newFetchResponse
 
     
 
