@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11894 2020-02-04 12:08:11Z Lavender $
+# $Id: admin.py 11930 2020-02-18 16:03:26Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-02-04 20:08:11 +0800 (週二, 04 二月 2020) $
-# $Revision: 11894 $
+# $Date: 2020-02-19 01:03:26 +0900 (週三, 19 二月 2020) $
+# $Revision: 11930 $
 
 import os
 import datetime
@@ -83,7 +83,7 @@ def createVersion(model, node, conflict=False):
     with open(fullPath, 'rb') as f:
         data = f.read()
 
-    dirName = hashlib.md5(toBytes(path)).hexdigest()
+    dirName = node.dirName
     checksum = hashlib.md5(data).hexdigest()
 
     createFile = False
@@ -202,14 +202,25 @@ def checkVersion(model):
         path = node.path
         dirName = hashlib.md5(toBytes(path)).hexdigest()
 
-        for version in Version.objects.filter(
-            dirName=dirName, conflict=True):
+        if version.conflict:
             conflictNodeList.append((node, version))
             logger.info(
                 "%s conflict: version %d and version %s" % (
                 path, version.number, version.preVersion.number))
 
     return conflictNodeList
+    
+def getConflictNodeList(model):
+    conflictNodeList = []
+    nodeList = model.objects.filter(type=FILE)
+    dirNameNodeTable = {node.dirName: node for node in nodeList}
+    dirNameList = [dirName for dirName in dirNameNodeTable]
+    versionList = Version.objects.filter(dirName__in=dirNameList, conflict=True)
+    for version in versionList:
+        node = dirNameNodeTable[version.dirName]
+        conflictNodeList.append((node, version))
+    return conflictNodeList
+        
 
 def loginCheck(sender, user, request, **kwargs):
     if user.is_superuser:
@@ -231,12 +242,12 @@ def loginCheck(sender, user, request, **kwargs):
             return mark_safe(msg)
 
         try:
-            conflictNodeList = checkVersion(Static)
+            conflictNodeList = getConflictNodeList(Static)
             for ele in conflictNodeList:
                 msg = createMessage(ele, Static)
                 messages.warning(request, msg)
 
-            conflictNodeList = checkVersion(Template)
+            conflictNodeList = getConflictNodeList(Template)
             for ele in conflictNodeList:
                 msg = createMessage(ele, Template)
                 messages.warning(request, msg)
@@ -374,7 +385,7 @@ class BaseFileAdmin(admin.ModelAdmin):
         return super(BaseFileAdmin, self).response_change(request, obj)
 
     def changelist_view(self, request, extra_context=None):
-        conflictNodeList = checkVersion(self.model)
+        conflictNodeList = getConflictNodeList(self.model)
 
         roots = self.model.objects.filter(level=0)
          
